@@ -7,10 +7,11 @@ from Shared.DC.Scripts.Bindings import Bindings
 from Errors import ValidationError
 from Products.Formulator.Widget import MultiItemsWidget
 from helpers import is_sequence, convert_unicode
-from Products.Formulator.i18n import translate as _
 
 from Products.PageTemplates.Expressions import SecureModuleImporter
 
+from zope.i18nmessageid import MessageIDFactory
+
 class Field:
     """Base class of all fields.
     A field is an object consisting of a widget and a validator.
@@ -127,12 +128,12 @@ class Field:
         # if normal value is a callable itself, wrap it
         if callable(value):
             return value.__of__(self)
-    
+
         # create message id for title and description in right domain
         if id in ['title', 'description']:
             i18n_domain = self.get_i18n_domain()
             if i18n_domain:
-                return _(value, i18n_domain)
+                return MessageIDFactory(i18n_domain)(value)
         return value
 
     # this also works if field is not in form for testing
@@ -204,21 +205,16 @@ class Field:
             # if we don't want message id, strip it off
             if not want_message_id:
                 try:
-                    # looks into message id internals..
-                    result = result.ustr
+                    # convert message id into unicode string
+                    result = unicode(result)
                 except AttributeError:
                     pass
             return result
-        if want_message_id:
-            # we do want a message id, so construct one from form domain
-            result = _(result, self.get_i18n_domain())
         else:
-            try:
-                # looks into message id internals..
-                result = result.ustr
-            except AttributeError:
-                pass
-        return result
+            if want_message_id:
+                # we do want a message id, so construct one from form domain
+                result = MessageIDFactory(self.get_i18n_domain())(result)
+            return result
     
     security.declarePrivate('_render_helper')
     def _render_helper(self, key, value, REQUEST):
