@@ -1,20 +1,15 @@
+import os, sys
+if __name__ == '__main__':
+    execfile(os.path.join(sys.path[0], 'framework.py'))
+
+from Testing import ZopeTestCase
+
+ZopeTestCase.installProduct('Formulator')
+
 import unittest, re
 from xml.dom.minidom import parseString
-
-import Zope
 from DateTime import DateTime
 
-# XXX this does not work for zope2.x if x < 3
-# can we fake this? should we do this?
-from Testing import makerequest
-
-try:
-    from Products.PlacelessTranslationService import translate
-    have_pts = 1
-except ImportError:
-    have_pts = 0
-
-
 from Products.Formulator.Form import ZMIForm
 from Products.Formulator.Errors import ValidationError, FormValidationError
 from Products.Formulator.MethodField import Method
@@ -30,27 +25,14 @@ from test_serialize import FakeRequest
     maybe could be moved to a "test_widgets" test case partially
 """
 
-class FormTestCase(unittest.TestCase):
-
-    def setUp(self):
-        get_transaction().begin()
-        # XXX compatibility with 2.7: the following does not work any longer
-        # self.connection = Zope.DB.open()
-        # instead do it ugly:
-        self.connection = Zope.app()._p_jar
-        self.root = makerequest.makerequest(
-            self.connection.root()['Application'])
+class FormTestCase(ZopeTestCase.ZopeTestCase):
 
+    def afterSetUp(self):
+        self.root = self.folder
         self.root.manage_addProduct['Formulator'] \
                  .manage_add('form', 'Test Form')
         self.form = self.root.form
-
-
-    def tearDown(self):
-        get_transaction().abort()
-        self.connection.close()
-
-
+        
     def test_has_field(self):
         """ test if has_field works, if one asks for a non-field attribute.
             this has raised AttributeError "aq_explicit" in previous versions
@@ -62,6 +44,13 @@ class FormTestCase(unittest.TestCase):
 
     def test_multi_list_items(self):
         self._test_list_items('MultiListField')
+
+    # the following two tests fail as their widgets do not support ints, etc
+    #def test_list_items(self):
+    #    self._test_list_items('RadioField')
+
+    #def test_multi_list_items(self):
+    #    self._test_list_items('MultiCheckBoxField')
         
     def _test_list_items(self, list_field_type):
         """ test if a list of values returned by TALES (override) expressions
@@ -134,15 +123,8 @@ class FormTestCase(unittest.TestCase):
         items1 = list_field.render( ('foo',) )
 
         list_field.tales['items'] = TALESMethod("python:('foo', 'bar')")
-        # NOTE: if PTS is installed, the i18n_translate_items
-        # also works as "input sanitizer" here converting the insane
-        # value returned from the tales expression to something Formulator's
-        # ListFields want to see
-        if have_pts:
-            self.assertEquals([('foo', 'foo'), ('bar', 'bar')], \
-                              list_field.get_value('items'))
-        else:
-            self.assertEquals(('foo', 'bar'), list_field.get_value('items'))
+        
+        self.assertEquals(('foo', 'bar'), list_field.get_value('items'))
         
         items2 = list_field.render( ('foo',) )
 
@@ -198,6 +180,14 @@ class FormTestCase(unittest.TestCase):
             {'field_int_field': '3'})
         self.assertEquals({'int_field': 3}, result)
 
+    def test_labels_with_direct_validation(self):
+        """ PloneFormMailer calls validate() directly on each field,
+        this used to give a KeyError as 'external_validator' wasn't
+        known for a label field.
+        """
+        self.form.manage_addField(
+            'label_field', 'Test Label Field', 'LabelField')
+        self.form['label_field'].validate(REQUEST=FakeRequest())
 
     def test_datetime_css_class_rendering(self):
         # test that a bug is fixed, which causing the css_class value
@@ -383,7 +373,7 @@ class FormTestCase(unittest.TestCase):
                               field.render_view(['a','c']))
             self.assertEquals('', field.render_view([]))
 
-    def test_default_to_now_does_not_overwite_request_values(self):
+    def test_default_to_now_does_not_overwrite_request_values(self):
         self.form.manage_addField('date_field','Test DateTime Field','DateTimeField')
         date_field = self.form.date_field
 
@@ -409,7 +399,7 @@ class FormTestCase(unittest.TestCase):
         self._helper_render_datetime(expected_values, rendered, type='text')
 
 
-    def test_checkbox_default_does_now_overwrite_submitted_values(self):
+    def test_checkbox_default_overwrites_submitted_values(self):
         
         self.form.manage_addField('checkbox_field','Test Checkbox','CheckBoxField')
         checkbox_field = self.form.checkbox_field
@@ -475,15 +465,44 @@ class FormTestCase(unittest.TestCase):
         self.assertEquals([u'item\xfc', u'item2'],
                           lines_field.get_value('default') )
 
+    def test_tales_none(self):
+        # test that a TALES default of None is rendered
+        # as the empty string in the field's value attribute
+        # and not as "value"
+        self.form.manage_addField('text','Text Field','StringField')
+        text = self.form.text
+        text.tales['default'] = TALESMethod('nothing')
+        self.assertEquals(1, text.render().count('value=""') )
+
+    def test_add_unicode_form(self):
+        # test bugfix when adding a form with a non-ascii title
+        # and the unicode flag set
+        self.root.manage_addProduct['Formulator'] \
+                 .manage_add('form2', 'Test Form b\xef\xbf\xbdr', unicode_mode=1)
+        form2 = self.root.form2
+        self.assertEquals(1, form2.get_unicode_mode())
+        self.assertEquals( type(u' '), type(form2.title))
+        self.assertEquals( u'Test Form b\ufffdr', form2.title)
+
+    def test_add_unicode_field(self):
+        # test bugfix when adding a field with a non-ascii title
+        # to a form with the unicode flag set
+        self.root.manage_addProduct['Formulator'] \
+                 .manage_add('form2', 'Test Form b\xef\xbf\xbdr', unicode_mode=1)
+        form2 = self.root.form2
+        self.assertEquals(1, form2.get_unicode_mode())
+        
+        form2.manage_addField('testfield', 'Test field b\xef\xbf\xbdr', \
+                              'StringField')
+        self.assertEquals(type(u' '), type(form2.testfield.title()))
+        self.assertEquals(u'Test field b\ufffdr', form2.testfield.title())
+        self.assertEquals(u'Test field b\ufffdr', form2.testfield.get_value('title'))
+
 
 def test_suite():
     suite = unittest.TestSuite()
-
-    suite.addTest(unittest.makeSuite(FormTestCase, 'test'))
+    suite.addTest(unittest.makeSuite(FormTestCase))
     return suite
 
-def main():
-    unittest.TextTestRunner().run(test_suite())
-
 if __name__ == '__main__':
-    main()
+    framework()
